badwing.characters.robot package
================================

Submodules
----------

badwing.characters.robot.brain module
-------------------------------------

.. automodule:: badwing.characters.robot.brain
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.robot.robot module
-------------------------------------

.. automodule:: badwing.characters.robot.robot
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.characters.robot
   :members:
   :undoc-members:
   :show-inheritance:
